@@ -1,67 +1,3 @@
-.addup.enum <-
-function () 
-{
-    weight = exp(pmpold + lprobold - null.lik)
-    inccount <<- inccount + weight * molddraw
-    msize <<- msize + weight * kold
-    cumsumweights <<- cumsumweights + weight
-    if (kold != 0) {
-        bm[c(position, K + position, 2 * K + kold, 3 * K + position)] = weight * 
-            c(b1, b2, 1, b1 > 0)
-        bmo <<- bmo + bm
-    }
-    else {
-        null.count <<- null.count + weight
-    }
-}
-.addup.enum.wotherstats <-
-function () 
-{
-    weight = exp(pmpold + lprobold - null.lik)
-    inccount <<- inccount + weight * molddraw
-    msize <<- msize + weight * kold
-    cumsumweights <<- cumsumweights + weight
-    if (kold != 0) {
-        bm[c(position, K + position, 2 * K + kold, 3 * K + position)] = weight * 
-            c(b1, b2, 1, b1 > 0)
-        bmo <<- bmo + bm
-    }
-    else {
-        null.count <<- null.count + weight
-    }
-    otherstats <<- lik.list[["otherstats"]]
-    add.otherstats <<- add.otherstats + weight * otherstats
-}
-.addup.mcmc <-
-function () 
-{
-    inccount <<- inccount + molddraw
-    msize <<- msize + kold
-    if (kold != 0) {
-        bm[c(position, K + position, 2 * K + kold, 3 * K + position)] = c(b1, 
-            b2, 1, b1 > 0)
-        bmo <<- bmo + bm
-    }
-    else {
-        null.count <<- null.count + 1
-    }
-}
-.addup.mcmc.wotherstats <-
-function () 
-{
-    inccount <<- inccount + molddraw
-    msize <<- msize + kold
-    if (kold != 0) {
-        bm[c(position, K + position, 2 * K + kold, 3 * K + position)] = c(b1, 
-            b2, 1, b1 > 0)
-        bmo <<- bmo + bm
-    }
-    else {
-        null.count <<- null.count + 1
-    }
-    otherstats <<- lik.list[["otherstats"]]
-    add.otherstats <<- add.otherstats + otherstats
-}
 .adjustdots <-
 function (dotargs, ...) 
 {
